---
title: "RNASeq notebook"
author: "Maroun"
date: "10/4/2018"
output: html_document
---

```{r setup, include=FALSE}
knitr::opts_chunk$set(echo = TRUE)
```

## R Markdown

This is an R Markdown document. Markdown is a simple formatting syntax for authoring HTML, PDF, and MS Word documents. For more details on using R Markdown see <http://rmarkdown.rstudio.com>.

When you click the **Knit** button a document will be generated that includes both content as well as the output of any embedded R code chunks within the document. You can embed an R code chunk like this:

```{r Import libraries}
suppressMessages(library(edgeR))
suppressMessages(library(rtracklayer))
```

```{r prepare gene ID to symbol conversion table from GTF file, echo=FALSE}
gtf <- rtracklayer::import('../data/wbcel235/celegans-genome/Caenorhabditis_elegans.WBcel235.89.gtf.gz')
conversionTable <- as.data.frame(mcols(gtf))
conversionTable <- conversionTable[conversionTable$type == "gene",]
rownames(conversionTable) <- conversionTable$gene_id
barplot(table(conversionTable$gene_biotype), las =2)
## keep only certain gene biotypes
genesToKeep <- conversionTable$gene_id[conversionTable$gene_biotype %in% c("antisense","lincRNA", "ncRNA", "protein_coding", "pseudogene")]
```


```{r Filtering, echo=FALSE}
countFiles <- list.files("../data/mapped/celegans-genome-mapping-3", pattern = ".HTseq$", full.names=TRUE)
DGE <- edgeR::readDGE(files = countFiles)
DGE$samples$SampleID <- gsub(".HTseq", "", DGE$samples$files)
DGE$samples$SampleID <- gsub("../data/mapped/celegans-genome-mapping-3/", "", DGE$samples$SampleID)
DGE$samples$Condition <- substr(DGE$samples$SampleID,1,nchar(DGE$samples$SampleID)-1)
DGE$samples$Condition <- factor(DGE$samples$Condition, levels = c("EV", "CCO", "HIS"))
DGE$samples$Replicate <-  substr(DGE$samples$SampleID,nchar(DGE$samples$SampleID),nchar(DGE$samples$SampleID))
design <- model.matrix(~0+Condition, DGE$samples)
#filter genes with very little read count
filter <- rowSums(DGE$counts > 5) > 3
table(filter)
DGE$counts <- DGE$counts[filter,]
DGE <- calcNormFactors(DGE)
```

```{r MDS plot, echo=FALSE}
plotMDS(DGE, main = "MDS plot of all samples", col = as.numeric(DGE$samples$Condition), labels = NULL, pch = 19)
legend(legend = unique(DGE$samples$Condition), x = 'bottomleft', pch = 19, col = as.numeric(unique(DGE$samples$Condition)))
```

```{r Van diagrams, echo=FALSE}
design <- model.matrix(~0 + Condition,DGE$samples)
contrasts <- makeContrasts(CCOeffect = ConditionCCO-ConditionEV, 
                           HISeffect = ConditionHIS-ConditionEV, levels = design)
v <- voom(DGE, design, plot = F, normalize = "quantile")
fit <- lmFit(v, design)
fit <- eBayes(fit)
fit2 <- contrasts.fit(fit = fit, contrasts = contrasts)
fit2 <- eBayes(fit2)
results <- decideTests(fit2, p.value = 0.05, lfc = 2)

vennDiagram(results,include=c("up","down"), counts.col = c("Red", "Blue"))
```


```{r Volcano plots, echo=FALSE}
tt <- lapply(colnames(contrasts), function(x){
  out <- topTable(fit2, n = Inf, coef = x)
  out$genes <- rownames(out)
  out$Contrast <- x
  out
})
tt <- do.call(rbind, tt)
tt$Symbol <- conversionTable$gene_name[match(tt$genes, conversionTable$gene_id)]
tt$Significant <- (abs(tt$logFC) > 2) & (tt$adj.P.Val < 0.05)
library(ggplot2)

vp <- ggplot(tt, aes(x = logFC, y = -log10(adj.P.Val), color = Significant)) + geom_point() + facet_wrap(~Contrast) +
  geom_hline(yintercept = -log10(0.05)) +
  geom_vline(xintercept = c(-2,2))
vp
```


```{r Interactive volcano plots, echo=FALSE}
library(plotly)
vp.interactive <- ggplot(tt[tt$Significant,], aes(x = logFC, y = -log10(adj.P.Val), gene_symbol = Symbol)) + geom_point() + facet_wrap(~Contrast) +
  geom_hline(yintercept = -log10(0.05)) +
  geom_vline(xintercept = c(-2,2))
ggplotly(vp.interactive)
```
